<div class="mdui-row mdui-row-gapless">
    <div class="mdui-col-xs-3">{{adminList}}</div>
    <div class="mdui-col-xs-1"></div>
    <div class="mdui-col-xs-7">
        <div class="mdui-typo-headline">信息</div><br><br>
        <form action="/adminwait/profile" method="POST">
            <div class="mdui-textfield"><i class="mdui-icon material-icons">title</i><input name="stuoe_name"
                    value="{{ serverconf['stuoe_name'] }}" type="text" class="mdui-textfield-input"
                    placeholder="论坛标题" />
                <div class="mdui-textfield-helper">取个好名字吧</div>
            </div>
            <div class="mdui-textfield"><i class="mdui-icon material-icons">textsms</i><label
                    class="mdui-textfield-label">介绍</label><textarea name="stuoe_des" class="mdui-textfield-input"
                    placeholder="简单的介绍下论坛吧" maxlength="2000">{{serverconf['stuoe_des']}}</textarea></div><button
                type="submit" class="mdui-btn mdui-btn-raised mdui-ripple mdui-color-theme-accent">更改并应用</button>
        </form>
    </div>
</div>