<div class="mdui-typo-headline">
   修改公开资料
  </div>
  <br />
  <br />
  <form action="/settings/profile" method="POST">
   <div class="mdui-textfield">
    <i class="mdui-icon material-icons">account_circle</i>
    <label class="mdui-textfield-label">昵称</label>
    <input name="nickname" class="mdui-textfield-input" type="nickname" value="{{ UserObj.nickname }}" maxlength="15" />
    <p class="help"></p>
   </div>
   <div class="mdui-textfield">
    <i class="mdui-icon material-icons">textsms</i>
    <label class="mdui-textfield-label">介绍</label>
    <textarea name="user_des" class="mdui-textfield-input" placeholder="简单的介绍下自己吧" maxlength="2000">{{UserObj.user_des}}</textarea>
   </div>
   <div class="mdui-textfield">
    <i class="mdui-icon material-icons">domain</i>
    <label class="mdui-textfield-label">个人主页域名</label>
    <input name="url" class="mdui-textfield-input" placeholder="自己的博客，Github地址" value="{{ UserObj.url }}" />
   </div>
   <br />
   <button type="submit" class="mdui-btn mdui-btn-raised mdui-ripple mdui-color-theme-accent">更新个人资料</button>
  </form>
  <br />
  <br />
  <div class="mdui-typo-headline">
   更改社交头像
  </div>
  <form action="/settings/avater" method="POST" enctype="multipart/form-data">
   <div class="mdui-textfield">
    <input style="position:absolute;opacity:0;" type="file" name="avater" />
    <img mdui-tooltip="{content: '上传头像'}" style="width: 60px;height: 60px;" class="mdui-img-circle" src="{{ UserObj.avater }}" />
    <br />
    <br />
    <input class="mdui-btn mdui-btn-raised mdui-ripple mdui-color-theme-accent" type="submit" value="上传" />
   </div>
  </form>
  <br />
  <br />
  <div class="mdui-typo-headline">
   更改或验证邮箱
  </div>
  <br />
  <br />
  <form action="/settings/email" method="POST">
   <div class="mdui-textfield">
    <label class="mdui-textfield-label">确认邮箱</label>
    <input name="email" class="mdui-textfield-input" type="nickname" value="{{ UserObj.email }}" />
   </div>
   <br />
   <button type="submit" class="mdui-btn mdui-btn-raised mdui-ripple mdui-color-theme-accent">请求并验证</button>
  </form>
  <br />
  <div class="mdui-typo-headline">
   更改密码
  </div><br />
  <br />
  <form action="/settings/password" method="POST">
   <div class="mdui-textfield">
    <label class="mdui-textfield-label">旧密码</label>
    <input name="oldpassword" class="mdui-textfield-input" type="password" value="" />
   </div>
   <div class="mdui-textfield">
    <label class="mdui-textfield-label">新密码</label>
    <input name="newpassword" class="mdui-textfield-input" type="password" value="" />
   </div>
   <div class="mdui-textfield">
    <label class="mdui-textfield-label">新密码(重复)</label>
    <input name="againpassword" class="mdui-textfield-input" type="password" value="" />
   </div>
   <br />
   <button type="submit" class="mdui-btn mdui-btn-raised mdui-ripple mdui-color-theme-accent">验证并修改</button>
  </form>
