<!DOCTYPE html>
<html>

<head>
  <meta charset="utf-8" />
  <title>{{ title }} - {{ webtitle }}</title>
  <link rel="stylesheet" href="/static/mdui/css/mdui.min.css" />
  <!-- Render for Jinja2 Building for https://github.com/stuoe/stuoe -->
</head>
<!-- Main content, definition style, occupancy percentage -->

<body
  class="mdui-color-theme-{{ colorPrimary }} mdui-theme-accent-{{ colorPrimary }} mdui-bottom-nav-fixed">
  <!-- Define color theme, set text style, body in body -->
  <div class="mdui-color-theme-theme">
    <!-- Define navigation bar -->
    <header class="mdui-shadow-0">
      {{ nav }}
    </header><br>
    <!-- Define the main content and adjust the percentage of occupied content -->
    <div class="mdui-container">
      {{ body }}
      <!-- Loading JavaScript -->
      <script src="/static/mdui/js/mdui.min.js"></script>
      <script>
        {{ js }}
      </script>
    </div>
  </div>
</body>

</html>