<style>
    .window {
        width: 400px;
        position: absolute;
        margin-left: -200px;
        margin-top: -80px;
        top: 35%;
        left: 50%;
        display: block;
        z-index: 2000;
    }
</style>
<div class="mdui-container window">
    <div class="mdui-container mdui-typo">
        <h2 align="left">400 恶意请求</h2>
        <h6 style="font-weight: 300;line-height: 1.2;">你的请求可能是恶意的，更改表单数据所造成，<a href="https://github.com/stuoe/stuoe">stuoe</a></a>
            拒绝你的请求，因此返回400</h6>
        <div class="mdui-divider"></div>
        <small>code:400 Bad Request</small>
    </div>
</div>