
Simditor.i18n =
  'zh-CN':
    'blockquote': '引用'
    'bold': '加粗文字'
    'code': '插入代码'
    'color': '文字颜色'
    'coloredText': '彩色文字'
    'hr': '分隔线'
    'image': '插入图片'
    'externalImage': '外链图片'
    'uploadImage': '上传图片'
    'uploadFailed': '上传失败了'
    'uploadError': '上传出错了'
    'imageUrl': '图片地址'
    'imageSize': '图片尺寸'
    'imageAlt': '图片描述'
    'restoreImageSize': '还原图片尺寸'
    'uploading': '正在上传'
    'indent': '向右缩进'
    'outdent': '向左缩进'
    'italic': '斜体文字'
    'link': '插入链接'
    'linkText': '链接文字'
    'linkUrl': '链接地址'
    'linkTarget': '打开方式'
    'openLinkInCurrentWindow': '在当前窗口中打开'
    'openLinkInNewWindow': '在新窗口中打开'
    'removeLink': '移除链接'
    'ol': '有序列表'
    'ul': '无序列表'
    'strikethrough': '删除线文字'
    'table': '表格'
    'deleteRow': '删除行'
    'insertRowAbove': '在上面插入行'
    'insertRowBelow': '在下面插入行'
    'deleteColumn': '删除列'
    'insertColumnLeft': '在左边插入列'
    'insertColumnRight': '在右边插入列'
    'deleteTable': '删除表格'
    'title': '标题'
    'normalText': '普通文本'
    'underline': '下划线文字'
    'alignment': '水平对齐'
    'alignCenter': '居中'
    'alignLeft': '居左'
    'alignRight': '居右'
    'selectLanguage': '选择程序语言'
    'fontScale': '字体大小'
    'fontScaleXLarge': '超大字体'
    'fontScaleLarge': '大号字体'
    'fontScaleNormal': '正常大小'
    'fontScaleSmall': '小号字体'
    'fontScaleXSmall': '超小字体'

  'en-US':
    'blockquote': 'Block Quote'
    'bold': 'Bold'
    'code': 'Code'
    'color': 'Text Color'
    'coloredText': 'Colored Text'
    'hr': 'Horizontal Line'
    'image': 'Insert Image'
    'externalImage': 'External Image'
    'uploadImage': 'Upload Image'
    'uploadFailed': 'Upload failed'
    'uploadError': 'Error occurs during upload'
    'imageUrl': 'Url'
    'imageSize': 'Size'
    'imageAlt': 'Alt'
    'restoreImageSize': 'Restore Origin Size'
    'uploading': 'Uploading'
    'indent': 'Indent'
    'outdent': 'Outdent'
    'italic': 'Italic'
    'link': 'Insert Link'
    'linkText': 'Text'
    'linkUrl': 'Url'
    'linkTarget': 'Target'
    'openLinkInCurrentWindow': 'Open link in current window'
    'openLinkInNewWindow': 'Open link in new window'
    'removeLink': 'Remove Link'
    'ol': 'Ordered List'
    'ul': 'Unordered List'
    'strikethrough': 'Strikethrough'
    'table': 'Table'
    'deleteRow': 'Delete Row'
    'insertRowAbove': 'Insert Row Above'
    'insertRowBelow': 'Insert Row Below'
    'deleteColumn': 'Delete Column'
    'insertColumnLeft': 'Insert Column Left'
    'insertColumnRight': 'Insert Column Right'
    'deleteTable': 'Delete Table'
    'title': 'Title'
    'normalText': 'Text'
    'underline': 'Underline'
    'alignment': 'Alignment'
    'alignCenter': 'Align Center'
    'alignLeft': 'Align Left'
    'alignRight': 'Align Right'
    'selectLanguage': 'Select Language'
    'fontScale': 'Font Size'
    'fontScaleXLarge': 'X Large Size'
    'fontScaleLarge': 'Large Size'
    'fontScaleNormal': 'Normal Size'
    'fontScaleSmall': 'Small Size'
    'fontScaleXSmall': 'X Small Size'
