<ul class="mdui-list mdui-list-dense">
  <li class="mdui-list-item mdui-ripple"><i class="mdui-list-item-icon mdui-icon material-icons">timeline</i>
    <div class="mdui-list-item-content">
      <div class="mdui-list-item-title">概览</div>
      <div class="mdui-list-item-text mdui-list-item-two-line"><a href="/admin/preview"><span
            class="mdui-text-color-theme-text">查看并分析</span>得到论坛的运作基本信息和统计</div></a>
    </div>
  </li>
  <li class="mdui-divider-inset mdui-m-y-0"></li>
  <li class="mdui-list-item mdui-ripple"><i class="mdui-list-item-icon mdui-icon material-icons">supervisor_account</i>
    <div class="mdui-list-item-content">
      <div class="mdui-list-item-title">资料</div>
      <div class="mdui-list-item-text mdui-list-item-two-line"><a href="/admin/profile"><span
            class="mdui-text-color-theme-text">论坛的信息</span>包括论坛的名称，论坛的介绍，爬虫与SEO优化等等</div></a>
    </div>
  </li>
  <li class="mdui-divider-inset mdui-m-y-0"></li>
  <li class="mdui-list-item mdui-ripple"><i class="mdui-list-item-icon mdui-icon material-icons">color_lens</i>
    <div class="mdui-list-item-content">
      <div class="mdui-list-item-title">样式</div>
      <div class="mdui-list-item-text mdui-list-item-two-line"><a href="/admin/style"><span
            class="mdui-text-color-theme-text">更改论坛的</span>色调，样式，主题。自定义header,footer等等</div></a>
    </div>
  </li>
  </li>
  <li class="mdui-divider-inset mdui-m-y-0"></li>
  <li class="mdui-list-item mdui-ripple"><i class="mdui-list-item-icon mdui-icon material-icons">inbox</i>
    <div class="mdui-list-item-content">
      <div class="mdui-list-item-title">标签</div>
      <div class="mdui-list-item-text mdui-list-item-two-line"><a href="/admin/tags"><span
            class="mdui-text-color-theme-text">查看并管理</span>帖子的标签分类，更改标签样式等等</div></a>
    </div>
  </li>
  <li class="mdui-divider-inset mdui-m-y-0"></li>
  <li class="mdui-list-item mdui-ripple"><i class="mdui-list-item-icon mdui-icon material-icons">extension</i>
    <div class="mdui-list-item-content">
      <div class="mdui-list-item-title">扩展</div>
      <div class="mdui-list-item-text mdui-list-item-two-line"><a href="/admin/extension"><span
            class="mdui-text-color-theme-text">安装并管理</span>扩展，扩展论坛的核心功能，享受更丰富的功能</div></a>
    </div>
  </li>
</ul>