<div> <br /> <br />{%if userObj==''%} <header>
		<div class="mdui-shadow-0 mdui-text-color-theme-icon" align="center">
			<div class="mdui-typo-headline" style="font-weight: 400;"> {{webtitle}} </div> <br />
			<div class="mdui-typo-subheading" style="font-weight: 300;"> {{des}} </div>
		</div> <br /> <br /> <br />
		<div class="mdui-divider"> </div> <br />
	</header> {%endif%} <div class="mdui-row mdui-row-gapless">
		<div class="mdui-col-xs-2">
			<div class="mdui-col">{%if userObj==''%} <button
				class="mdui-btn mdui-btn-raised mdui-btn-block mdui-ripple mdui-color-grey">
				<div mdui-tooltip="{content: '注册/登入'}" mdui-menu="{target: '#account-op'}"
					class="mdui-text-color-white" style="text-decoration: none;font-weight: 300;color:#0c0d0e;">
					需要登入 </div>
				</button>{%else%} <button
				class="mdui-btn mdui-btn-raised mdui-btn-block mdui-ripple mdui-color-theme-accent">
				<div class="mdui-text-color-white" style="font-weight:700;"> <a class="mdui-text-color-white"
						href="/write" style="text-decoration: none;font-weight: 300;color:#0c0d0e;">开始讨论</a> </div>
				</button>{%endif%}<br>
				<ul class="mdui-list mdui-list-dense">
				{% if options == 'index'%}
				<li class="mdui-list-item mdui-ripple"> <i
						class="mdui-list-item-icon mdui-icon material-icons mdui-text-color-theme-accent">forum</i>
					<div class="mdui-list-item-content"> <a href="/" class="mdui-text-color-theme-accent">所有讨论</a>
					</div>
					{% else %}
				<li class="mdui-list-item mdui-ripple"> <i
						class="mdui-list-item-icon mdui-icon material-icons">chat</i>
					<div class="mdui-list-item-content"> <a href="/">所有讨论</a> </div>
					{% endif %}
				</li> {%if not userObj==''%} {% if options == 'my'%}<li
					class="mdui-list-item mdui-ripple mdui-text-color-theme-accent"> <i
						class="mdui-list-item-icon mdui-icon material-icons mdui-text-color-theme-accent">my_location</i>
					<div class="mdui-list-item-content"> <a href="/my" class="mdui-text-color-theme-accent">我的帖子</a>
					</div>
				</li>{%else%}
				<li class="mdui-list-item mdui-ripple"> <i
						class="mdui-list-item-icon mdui-icon material-icons">my_location</i>
					<div class="mdui-list-item-content"> <a href="/my">我的帖子</a> </div>{%endif%}
				<li class="mdui-list-item mdui-ripple"> <i
						class="mdui-list-item-icon mdui-icon material-icons">notifications</i>
					<div class="mdui-list-item-content"> <a href="/notifications">通知</a> </div>
				</li> {%endif%} 
				
				{%for sidebar in some_sidebar %} 
				<li class="mdui-list-item mdui-ripple"> <i
					class="mdui-list-item-icon mdui-icon material-icons">{{ sidebar["icon"] }}</i>
				<div class="mdui-list-item-content"> <a href="{{ sidebar["url"] }}">{{ sidebar["name"] }}</a> </div>
				</li>
				{%endfor%}
				<li class="mdui-divider"></li> {%for i in tagslist%} <li
					class="mdui-list-item mdui-ripple"> <i
						class="mdui-list-item-icon mdui-icon material-icons">{{i.icon}}</i>
					<div class="mdui-list-item-content"> <a href="/t/{{ i.id }}">{{i.name}}</a> </div>
				</li> {%endfor%}
				</ul>
				</div>
		</div>
		<div class="mdui-col-xs-9"> {%for post in postlist%} <li class="mdui-list-item">
				<div class="mdui-list-item-avatar"> <img src="{{ get_avater(post.pusher) }}" /> </div>
				<div class="mdui-list-item-content"> <a href="/p/{{ post.id }}"
						style="text-decoration: none;font-weight: 300;color:#0c0d0e;">
						<h3 class="mdui-typo-subheading" style="line-height: 0;">{{post.title}}</h3> <small
							style="line-height: 0;">{{ post.state() }}</small>
						<p class="mdui-typo-body-1" style="line-height: 1;">
							{{ post.body | striptags | upper | trim | truncate(180, True) }} </p>
					</a> </div> {%if post.lock==True%} <i class="mdui-icon material-icons"
					mdui-tooltip="{content: '讨论已被锁定'}"
					style="color: #1C6BF5;line-height: 0;">lock</i>{%endif%}{%if post.top%} <i
					class="mdui-icon material-icons" mdui-tooltip="{content: '讨论已被顶置'}"
					style="color: #FF0000;line-height: 0;">assistant_photo</i>{%endif%}{%if userObj in post.star_user_list and auth%}<i
					class="mdui-icon material-icons" mdui-tooltip="{content: '星标讨论'}"
					style="color:#FFC300;">stars</i>{% endif %} {% if auth %} <i class="mdui-icon material-icons mdui-btn-icon"
					mdui-menu="{target: '#post-op-{{ post.id }}'}">more_vert</i>{% else %} <i
					class="mdui-icon material-icons"></i>{% endif %} <br> <br> <br>
				<ul class="mdui-menu" id="post-op-{{ post.id }}">
					<li class="mdui-menu-item">{%if userObj in post.star_user_list and auth%}{%else%} <a
							class="mdui-ripple" href="/stared/{{ post.id }}"> <i
								class="mdui-menu-item-icon mdui-icon material-icons">star_border</i>设为星标</a></li>
					<li class="mdui-divider"></li> {%endif%} <li class="mdui-menu-item"> <a class="mdui-ripple"
							href="/p/{{ post.id }}#reply" style="text-decoration: none;color:#0c0d0e;"> <i
								class="mdui-menu-item-icon mdui-icon material-icons">chat_bubble</i>回复</a></li>
					{%if userObj.user_group=='管理员'and auth and not post.top%} <li class="mdui-menu-item"> <a
							class="mdui-ripple" href="/top/{{post.id}}"> <i
								class="mdui-menu-item-icon mdui-icon material-icons">pin_drop</i>设为顶置</a></li>
					{%endif%}{%if userObj.user_group=='管理员'and auth and post.top%} <li class="mdui-menu-item"> <a
							class="mdui-ripple" href="/untop/{{post.id}}"> <i
								class="mdui-menu-item-icon mdui-icon material-icons">pin_drop</i>取消顶置</a></li>
					{%endif%}{%if post.lock==False and userObj.user_group=='管理员'and auth%} <li class="mdui-menu-item">
						<a class="mdui-ripple" href="/lock/{{post.id}}"> <i
								class="mdui-menu-item-icon mdui-icon material-icons">lock</i>锁定</a></li>
					{%endif%}{%if post.lock and userObj.user_group=='管理员'and auth%} <li class="mdui-menu-item"> <a
							class="mdui-ripple" href="/unlock/{{post.id}}"> <i
								class="mdui-menu-item-icon mdui-icon material-icons">lock_open</i>取消锁定</a></li>
					{%endif%}{%if (userObj.user_group=='管理员'or userObj.id == post.pusher) or auth%} <li
						class="mdui-menu-item"> <a class="mdui-ripple" href="/rmpost/{{post.id}}"> <i
								class="mdui-menu-item-icon mdui-icon material-icons">delete</i>删除</a></li> {%endif%}
				</ul>
			</li>
			<div class="mdui-divider"></div> {%endfor%}{%if postlist==[]or postlist==''%} <br /> <br /> <br /> <br />
			<br /> <br /> <br />
			<div class="mdui-typo" align="center">
				<p> <strong>这里看起来什么都没有</strong> </p>
			</div> {%endif%}
		</div>
	</div>
</div>